import java.awt.*;
import java.awt.event.*;

/**
 * Diese Klasse definiert spezielle Frames fr den einsamen PacMan.
 * Solch ein Frame ist das sichtbare Fenster im Fensterlesystem
 * (also z.&nbsp;B. X oder MS Windows).
 */
public class LPMFrame extends Frame implements WindowListener {

  /** Knopf zum Bewegen nach links. */
  private Button m_leftButton = null;

  /** Knopf zum Bewegen nach rechts. */
  private Button m_rightButton = null;

  /** Knopf zum Bewegen nach oben. */
  private Button m_upButton = null;

  /** Knopf zum Bewegen nach unten. */
  private Button m_downButton = null;

  /** Das Panel, in dem der PacMan sichtbar wird. */
  private LPMPanel m_lpmArea = null;

  /** Unser PacMan. */
  private PacMan m_pacMan = null;

  /** Der Konstruktor. */
  public LPMFrame () {
    // Navigationsschaltflchen erzeugen
    // beachte: der Parameter ist zugleich Beschriftung und Kommando
    m_leftButton = new Button(PacMan.MOVE_LEFT);
    m_rightButton = new Button(PacMan.MOVE_RIGHT);
    m_upButton = new Button(PacMan.MOVE_UP);
    m_downButton = new Button(PacMan.MOVE_DOWN);
    // PacMan erzeugen
    m_pacMan = new PacMan();
    // Panel erzeugen
    m_lpmArea = new LPMPanel(m_pacMan);
    // Schaltflchen einfgen
    // beachte: standardmig wird ein BorderLayout verwendet, der die
    // Komponenten nach Himmelsrichtungen verteilt
    add(m_leftButton, "West");
    add(m_rightButton, "East");
    add(m_upButton, "North");
    add(m_downButton, "South");
    add(m_lpmArea, "Center");
    // PacMan selbst soll auf die Schaltflchenaktionen ("gedrckt") lauschen
    m_leftButton.addActionListener(m_pacMan);
    m_rightButton.addActionListener(m_pacMan);
    m_upButton.addActionListener(m_pacMan);
    m_downButton.addActionListener(m_pacMan);
    // Beschriftung fr den Fensterlerahmen
    setTitle("Lonely PacMan");
    // das hiesige Objekt lauscht auf Fensterereignisse, insbesondere
    // "Fenster schlieen"
    addWindowListener(this);
  }

  /**
   * Diese Methode beendet die gesamte Applikation. Sie wird aktiviert,
   * wenn der Schlieen-Knopf vom Fenster bettigt wird.
   */
  public void windowClosing(WindowEvent e) {
    LonelyPacManApp.exit();
  }

  /** Diese Implementierung macht nichts. */
  public void windowOpened(WindowEvent e) {}
  /** Diese Implementierung macht nichts. */
  public void windowClosed(WindowEvent e) {}
  /** Diese Implementierung macht nichts. */
  public void windowIconified(WindowEvent e) {}
  /** Diese Implementierung macht nichts. */
  public void windowDeiconified(WindowEvent e) {}
  /** Diese Implementierung macht nichts. */
  public void windowActivated(WindowEvent e) {}
  /** Diese Implementierung macht nichts. */
  public void windowDeactivated(WindowEvent e) {}
} 
