import java.applet.Applet;
import java.awt.*;

/**
 * Diese Klasse reprsentiert die gesamte Applikation "einsamer PacMan"
 * (besser gesagt: alle Applikationen).
 * Sie kann sowohl als eigenstndige Java-Applikation als auch als
 * Java-Applet verwendet werden.
 */
public class LonelyPacManApp extends Applet {

  /**
   * Die Referenz auf die Applikation. Wird nur belegt, wenn das Programm
   * tatschlich als Applikation gestartet wird; wird es als Applet gestartet,
   * bleibt sie <code>null</code>.
   */
  private static LonelyPacManApp m_application = null;

  /** Das Hauptfenster. */
  private Frame m_mainFrame = null;

  /**
   * Diese Methode aktiviert die Applikation/das Applet.
   * Wird "einsamer PacMan" als Applet gestartet, so wird diese Methode
   * automatisch vom Rahmenwerk (z.&nbsp;B. Internetbrowser) aktiviert.
   */
  public void init () {
    // Hauptfenster erzeugen, alles weitere geschieht darin
    m_mainFrame = new LPMFrame();
    // Hauptfenster initialiseren
    m_mainFrame.pack();
  }

  /////////////////////////////////////////////////////////////////////////
  //
  // spezielle Behandlung fr die Programmaktivierung als Applikation
  //

  /**
   * Standardmethode zum Starten als Applikation.
   * @param args Kommandozeilenparameter. Sie werden nicht ausgewertet.
   */
  public static void main (String[] args) {
    // es wird genau eine Applikation erzeugt
    m_application = new LonelyPacManApp();
    // und gestartet
    m_application.init();
    m_application.start();
  }

  /**
   * Diese Methode bewirkt, da das Programm beendet wird, wenn es als
   * Applikation gestartet wurde. Wurde sie als Applet aktiviert, ist sie
   * wirkungslos.
   */
  public static void exit () {
    if (m_application != null) {
      System.exit(0);
    }
  }

  /////////////////////////////////////////////////////////////////////////
  //
  // spezielle Behandlung fr die Programmaktivierung als Applet
  //

  /**
   * Diese Methode wird automatisch aufgerufen, wenn das Programm als
   * Applet gestartet wurde und beendet werden soll.
   */
  public void destroy () {
    // Hauptfenster schlieen
    m_mainFrame.dispose();
    m_mainFrame = null;
  }

  /**
   * Diese Methode wird automatisch aufgerufen, wenn das Programm als
   * Applet gestartet wurde und (re-)aktiviert werden soll.
   */
  public void start () {
    // Hauptfenster anzeigen
    m_mainFrame.setVisible(true);
  }

  /**
   * Diese Methode wird automatisch aufgerufen, wenn das Programm als
   * Applet gestartet wurde und schlafen gelegt werden soll.
   */
  public void stop () {
    // Hauptfenster verstecken
    m_mainFrame.setVisible(false);
  }
} 
